document.addEventListener('DOMContentLoaded', () => {
  // Create animated charts
  const charts = document.querySelectorAll('.chart');
  charts.forEach(chart => {
    createChart(chart);
  });
});

function createChart(element) {
  const canvas = document.createElement('canvas');
  element.appendChild(canvas);
  const ctx = canvas.getContext('2d');
  
  // Set canvas size
  canvas.width = element.offsetWidth;
  canvas.height = element.offsetHeight;
  
  // Generate random data points
  const points = Array.from({length: 10}, () => Math.random() * 80 + 10);
  
  // Draw chart
  ctx.beginPath();
  ctx.strokeStyle = '#6366f1';
  ctx.lineWidth = 2;
  
  points.forEach((point, index) => {
    const x = (index / (points.length - 1)) * canvas.width;
    const y = canvas.height - (point / 100) * canvas.height;
    
    if (index === 0) {
      ctx.moveTo(x, y);
    } else {
      ctx.lineTo(x, y);
    }
  });
  
  ctx.stroke();
  
  // Add gradient
  const gradient = ctx.createLinearGradient(0, 0, 0, canvas.height);
  gradient.addColorStop(0, 'rgba(99, 102, 241, 0.2)');
  gradient.addColorStop(1, 'rgba(99, 102, 241, 0)');
  
  ctx.lineTo(canvas.width, canvas.height);
  ctx.lineTo(0, canvas.height);
  ctx.fillStyle = gradient;
  ctx.fill();
}

// Handle window resize
window.addEventListener('resize', () => {
  const charts = document.querySelectorAll('.chart');
  charts.forEach(chart => {
    chart.innerHTML = '';
    createChart(chart);
  });
});